Thread (14 messages) 14 messages, 3 authors, 2017-01-20

Lifecycle

  1. Posted hanjun.guo@linaro.org (Hanjun Guo)

[PATCH v13 1/7] arm64: Rename the common MADT parse routine

From: Hanjun Guo <hidden>
Date: 2017-01-19 03:51:28
Also in: linux-acpi

Hi Jeremy,

On 2017/1/18 4:50, Jeremy Linton wrote:
quoted hunk ↗ jump to hunk
The MADT parser in smp.c is now being used to parse
out NUMA, PMU and ACPI parking protocol information as
well as the GIC information for which it was originally
created. Rename it to avoid a misleading name.

Signed-off-by: Jeremy Linton <redacted>
---
 arch/arm64/kernel/smp.c | 13 +++++++------
 1 file changed, 7 insertions(+), 6 deletions(-)
diff --git a/arch/arm64/kernel/smp.c b/arch/arm64/kernel/smp.c
index cb87234..8ea244c 100644
--- a/arch/arm64/kernel/smp.c
+++ b/arch/arm64/kernel/smp.c
@@ -517,13 +517,14 @@ static unsigned int cpu_count = 1;

 #ifdef CONFIG_ACPI
 /*
  * acpi_map_gic_cpu_interface - parse processor MADT entry
  *
  * Carry out sanity checks on MADT processor entry and initialize
- * cpu_logical_map on success
+ * cpu_logical_map, the ACPI parking protocol, NUMA mapping
+ * and the PMU interrupts on success
  */
 static void __init
-acpi_map_gic_cpu_interface(struct acpi_madt_generic_interrupt *processor)
+acpi_verify_and_map_madt(struct acpi_madt_generic_interrupt *processor)
@@ -517,13 +517,14 @@ static unsigned int cpu_count = 1;
 #ifdef CONFIG_ACPI
 /*
- * acpi_map_gic_cpu_interface - parse processor MADT entry
+ * acpi_verify_and_map_madt - parse processor MADT entry
  *
  * Carry out sanity checks on MADT processor entry and initialize
Nit, MADT is a table includes multi type of table entries, we just
need to map the the processor type, how about updating it to
acpi_verify_and_map_madt_processor()?

Thanks
Hanjun
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help